Module eloreta

Module eloreta 

eLORETA (exact Low Resolution Electromagnetic Tomography) solver.

Ported from MNE-Python’s mne.minimum_norm._eloreta._compute_eloreta.

eLORETA iteratively computes optimal source weights that yield exact localisation (zero localisation bias) for single dipole sources.

References

Pascual-Marqui, R. D. (2011). Discrete, 3D distributed, linear imaging methods of electric neuronal activity. Part 1: exact, zero error localization. arXiv:0710.3341.

Functions

compute_eloreta
Compute the eLORETA inverse kernel.